# tstrait

**tstrait** is a quantitative trait simulator of [tskit](https://tskit.readthedocs.io/) tree sequences.

- Documentation: https://tskit.dev/tstrait/docs/
- Source code: https://github.com/tskit-dev/tstrait
- Tree sequence documentation: https://tskit.dev/learn/

It provides:
- Simulation of quantitative traits
- Simulation of genetic effect sizes from various distributions
- Simulation of pleiotropic phenotypes
- Simulation of environmental noise
- Computation of individual genetic values given the effect sizes of causal mutations